<?php
/**
 * Template part for displaying a 404 page.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Astra
 * @since 1.2.7
 */

?>

<?php astra_entry_before(); ?>

<section class="error-404 not-found">

	<?php astra_entry_top(); ?>

	<?php astra_entry_content_404_page(); ?>

	<?php astra_entry_bottom(); ?>

</section><!-- .error-404 -->

<?php astra_entry_after(); ?>
