.gallery-item{display:inline-block;text-align:center;vertical-align:top;width:100%}.gallery-columns-2 .gallery-item{max-width:50%}.gallery-columns-3 .gallery-item{max-width:33.33%}.gallery-columns-4 .gallery-item{max-width:25%}.gallery-columns-5 .gallery-item{max-width:20%}.gallery-columns-6 .gallery-item{max-width:16.66%}.gallery-columns-7 .gallery-item{max-width:14.28%}.gallery-columns-8 .gallery-item{max-width:12.5%}.gallery-columns-9 .gallery-item{max-width:11.11%}.gallery-caption{display:block}.ast-blog-featured-section .gallery{margin-bottom:0}.single .entry-content .gallery{margin-right:-10px;margin-left:-10px}.gallery-caption{color:var(--ast-gallery-block-color);padding:10px;border-radius:0 0 2px 2px;border:1px solid var(--ast-border-color);border-top:none;font-size:.9em}.gallery-icon{border-bottom:0;border-radius:2px 2px 0 0;border:1px solid var(--ast-border-color);overflow:hidden}.gallery-item{margin:0;padding:10px;border-radius:2px}.gallery-item:last-child{margin-bottom:2em}.elementor-image-gallery .gallery-icon{border:none}