#customize-theme-controls .customize-pane-child.current-section-parent,.in-sub-panel #customize-theme-controls .customize-pane-child.current-panel-parent{transform:translateX(100%)}#customize-controls .control-section.control-section-ast_section .accordion-section-title{color:#555d66;background-color:#fff;border-bottom:1px solid #ddd;border-right:4px solid #fff;transition:.15s color ease-in-out,.15s background-color ease-in-out,.15s border-color ease-in-out}#customize-controls .control-section.control-section-ast_section .accordion-section-title:after{color:#a0a5aa}#customize-controls .control-section.control-section-ast_section .accordion-section-title:focus,#customize-controls .control-section.control-section-ast_section .accordion-section-title:hover{color:#0073aa;background:#f3f3f5;border-right-color:#0073aa}#customize-controls .control-section.control-section-ast_section .accordion-section-title:hover:after{color:#0073aa}#customize-controls .control-section-ast_section .accordion-section{margin-right:-24px;margin-left:-24px}.customize-section-description .astra-section-description ul{margin:0}.customize-section-description .astra-section-description ul>li{list-style-type:none}.customize-section-description .astra-section-description ul>li:last-child{margin-bottom:0}.astra-section-description a{text-decoration:none;font-style:italic;border-bottom:1px dotted transparent;transition:all ease-in-out .3s}.astra-section-description a:hover{border-bottom-color:inherit}#customize-controls .control-section-ast_section .customize-info .customize-section-description{margin-bottom:0}.customize-widgets-header{margin-right:-24px;margin-left:-24px}#customize-sidebar-outer-content{height:calc(100vh - 46px)}