.gform_wrapper form{position:relative}.gform_wrapper .ui-datepicker-header select{padding:inherit}.gform_wrapper .gform_body .gfield_checkbox li>label{margin-top:4px}.gform_wrapper input:not([type=submit]):focus,.gform_wrapper select:focus,.gform_wrapper textarea:focus{background-color:#fff;border-color:var(--ast-border-color);outline:0;box-shadow:none}.ui-datepicker-header select{padding:0}@media (max-width:768px){.gform_wrapper.gf_browser_chrome form>.gform_body{width:100%}}