#ast-scroll-top{z-index:9999}.ast-sticky-add-to-cart{position:fixed;right:0;left:0;opacity:0;z-index:1200;transition:opacity .4s ease-in-out,transform .6s ease-in-out,outline .15s ease;transform:translate(0,0);background-color:var(--ast-global-color-primary,var(--ast-global-color-5))}.ast-sticky-add-to-cart.is-active{transform:translate(0,0);opacity:1}.ast-sticky-add-to-cart .ast-sticky-add-to-cart-content{display:flex;min-height:60px;padding:10px 0}.ast-sticky-add-to-cart .ast-sticky-add-to-cart-content .ast-sticky-add-to-cart-title-wrap{display:flex;align-items:center;flex-grow:1}.ast-sticky-add-to-cart .ast-sticky-add-to-cart-content .ast-sticky-add-to-cart-title-wrap img{max-height:50px;width:auto}.ast-sticky-add-to-cart .ast-sticky-add-to-cart-content .ast-sticky-add-to-cart-title-wrap .ast-sticky-add-to-cart-title{padding:5px 20px;font-size:18px;font-weight:inherit;line-height:1.5}.ast-sticky-add-to-cart .ast-sticky-add-to-cart-content .ast-stock-detail{display:none}.ast-sticky-add-to-cart-action-wrap{display:flex;align-items:center;justify-content:flex-end}.ast-sticky-add-to-cart-action-wrap .ast-quantity-add-to-cart{display:flex;align-items:flex-start}.ast-sticky-add-to-cart-action-wrap .cart{display:flex;align-items:center}.ast-sticky-add-to-cart-action-wrap .quantity{padding-left:14px}.ast-sticky-add-to-cart-action-wrap .quantity.ast-vertical-style-applied{margin-left:1em}.ast-sticky-add-to-cart-action-wrap .ast-sticky-add-to-cart-action-price{font-weight:700;padding-left:20px}.ast-sticky-add-to-cart-action-wrap .ast-sticky-add-to-cart-action-price del{opacity:.5;font-weight:400}.woocommerce div.ast-sticky-add-to-cart-action-wrap .button.single_add_to_cart_button{padding:11px 25px;width:100%}