.astra-review-notice-container {
	display: flex;
	align-items: center;
	padding-top: 10px;
}

.astra-review-notice-container .dashicons {
    font-size: 1.4em;
	padding-left: 10px;
}

.astra-review-notice-container a {
    padding-left: 5px;
    text-decoration: none;
}

.astra-review-notice-container .dashicons:first-child {
    padding-left: 0;
}

.astra-notice-container .notice-image img {
    max-width: 90px;
}

.astra-notice-container .notice-content .notice-heading {
    padding-bottom: 5px;
}

.astra-notice-container .notice-content {
    margin-left: 15px;
}

.astra-notice-container {
    padding-top: 10px;
    padding-bottom: 10px;
    display: flex;
    justify-content: left;
    align-items: center;
}