.e-global__preview-item.e-global__color[data-global-id="astratextcolor"] {
    border-top: 2px solid #404349;
}
.e-global__color[data-global-id^="astra"] {
    background: rgb(64 67 73 / 30%);
    padding-top: 8px;
    padding-bottom: 8px;
    border-bottom: 0;
    border-top: 0;
    margin-top: 0;
    margin-bottom: 0;
}
.e-global__preview-item.e-global__color[data-global-id="astraextracolor4"] {
    border-bottom: 2px solid #404349;
}
